@@ -21,7 +21,7 @@
     <message>
         <location filename="../src/core/ui/about.cpp" line="102"/>
         <source>It is a light and powerful application, written in Qt.</source>
-        <translation>Essa é um aplicativo leve e poderoso, escrito em Qt.</translation>
+        <translation>Esse é um aplicativo leve e poderoso, escrito em Qt.</translation>
     </message>
     <message>
         <location filename="../src/core/ui/about.cpp" line="105"/>
@@ -378,7 +378,7 @@
     <message>
         <location filename="../src/core/ui/mainwindow.cpp" line="341"/>
         <source>Screenshot </source>
-        <translation>Screenshot </translation>
+        <translation>Captura de tela </translation>
     </message>
     <message>
         <location filename="../src/core/ui/mainwindow.ui" line="157"/>
@@ -404,7 +404,10 @@
 right click to fit to edges,
 double click or press Enter
 to take a screenshot.</source>
-        <translation type="unfinished"></translation>
+        <translation>Clique e arraste para desenhar um retângulo,
+clique direito para encaixar nas bordas,
+clique duplo ou pressione Enter,
+para tirar uma screenshot.</translation>
     </message>
     <message>
         <location filename="../src/core/regionselect.cpp" line="202"/>
@@ -655,12 +658,13 @@ to take a screenshot.</source>
         <location filename="../src/core/ui/configwidget.ui" line="407"/>
         <source>If this is unchecked, the selected area
 might become larger to fit to outer edges</source>
-        <translation type="unfinished"></translation>
+        <translation>Se isto estiver desmarcado, a área selecionada
+pode ficar maior para se ajustar às bordas externas</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="411"/>
         <source>Fit to edges inside selected area by right clicking</source>
-        <translation type="unfinished"></translation>
+        <translation>Encaixe as bordas dentro da área selecionada com o botão direito</translation>
     </message>
     <message>
         <location filename="../src/core/ui/configwidget.ui" line="458"/>
